# Core

```{eval-rst}
.. module:: annsel.core
```

```{eval-rst}
.. currentmodule:: annsel
```

## Selectors

```{eval-rst}
.. autosummary::
    :toctree: ../generated

    obs_col
    obs_names
    var_col
    var_names
    x
```
